==> oda-framework-0.1.72090.tgz: package/components/grids/table/$info/props/_info.js <==
export default [
    { label: 'size', src: './$info/props/size.md', title: 'Количество строк, которые находятся на данный момент в дереве', color: 'green' },
    { label: 'items', src: './$info/props/items.md', title: 'Содержит список всех развернутых узлов, которые находятся в контейнере дерева на данный момент', color: 'green' },
    { label: 'iconSize', src: './$info/props/icon-size.md', title: 'Задает высоту строк, которые используются для отображения узлов дерева с иконками или без них', color: 'yellow', error: 'Если задаешь свойство icon в списке узлов dataSet, то иконка не выводится. Нужно создавать пользовательский шаблон. Это очень не удобно использовать'},
    { label: 'showTreeLines', src: './$info/props/show-tree-lines.md', title: 'Показывает горизонтальные линии у узлов дерева, расположенных на одном и том же уровне', color: 'yellow', error: 'Направляющие линии отображаются ниже узлов. При изменении свойства отображение линий не меняется' },
    { label: 'categories', src: './$info/props/categories.md', title: 'содержит дополнительные настройки, которые используются в процессе группировки узлов дерева', color: 'green' },
    { label: 'selectAll', src: './$info/props/select-all.md', title: 'Позволяет выбрать все узлы дерева', color: 'green' },
    { label: 'allowSort', src: './$info/props/allow-sort.md', title: 'Позволяет сортировать узлы дерева по возрастанию или убыванию', color: 'red', error: 'Стрелка для сортировки изначально не появляется. Сортировка идет только по убыванию. При сортировке по возрастанию списка узлов не обновляется, но если развернуть вложенный узел, то они сортируются. После отмены сортировки толи не возвращает все обратно, толи просто не обновляет' },
    { label: 'screen', src: './$info/props/screen.md', title: 'Содержит объект, позволяющий определить, какие узлы умещаются в видимой области контейнера, какие отсортированы и/или отфильтрованы', color: 'green' },
    { label: 'idName', src: './$info/props/idName.md', title: 'Задает уникальный идентификатор строки', color: 'red', error: 'Оно просто содержит ошибку, это не массив в 166 строке table.js' },
    { label: 'lazy', src: './$info/props/lazy.md', title: 'Позволяет ускорить обработку узлов дерева, исключив из общего списка не отображаемые узлы', color: 'red', error: 'При наличии футора он не не правильно считает количество видимых строк в контейнере. Он одну лишнюю добавляет' },
    { label: 'loadingTemplate', src: './$info/props/loading-template.md', title: 'Содержит имя компонента, который используется для отображения узлов в режиме ожидания окончания загрузки их дочерних узлов', color: 'green' },
    { label: 'footer', src: './$info/props/footer.md', title: 'Позволяет узнать содержимое нижнего колонтитула дерева', color: 'green' },
    { label: 'rows', src: './$info/props/rows.md', title: 'Содержит список всех узлов, которые необходимы для обработки узлов в видимой области контейнера дерева',  color: 'green' },
    { label: 'table', src: './$info/props/table.md', title: 'Содержит указатель на сам компонент', color: 'red' },
    { label: 'allowSelection', src: './$info/props/allow-selection.md', title: 'Включает режим, позволяющий выбирать необходимые узлы дерева', color: 'green' },
    { label: 'selection', src: './$info/props/selection.md', title: 'Содержит список всех выбранных узлов дерева', color: 'red', error: 'При выборе всех строк selectAll массив не заполняется' },
    { label: 'settingsId', src: './$info/props/settings-id.md', title: 'Задает имя, которое используется при чтении или сохранении некоторых текущих настроек компонента в локальном хранилище', color: 'green' },
    { label: 'headerHeight', src: './$info/props/header-height.md', title: 'Позволяет определить высоту заголовка компонента', color: 'green' },
    { label: 'footerHeight', src: './$info/props/footer-height.md', title: 'Позволяет определить высоту нижнего колонтитула компонента', color: 'red', error: 'Не пересчитывает высоту. Она всегда остается 0' },
    { label: 'filters', src: './$info/props/filters.md', title: 'Содержит массив столбцов, в которых включен режим фильтрации узлов дерева', color: 'red', error: 'Любой заданный фильтр убирает все строки таблицы' },
    { label: 'sorts', src: './$info/props/sorts.md', title: 'Содержит массив столбцов, которые находятся в режиме сортировки', color: 'red', error: 'если не задан явно массив columns, то сортировка не работает. Проблема с cols. Иконка сортировки изначально не появляется. Сортировка узлов не обновляется до переоткрытия узлов в ручном режиме.' },
    { label: 'groups', src: './$info/props/groups.md', title: 'Содержит массив столбцов, по которым осуществляется группировка узлов дерева на данный момент', color: 'yellow', error: 'С массивом все хорошо, но группировка отображается только тогда, когда переоткроешь какую-нибудь группу' },
    { label: 'allowFocus', src: './$info/props/allow-focus.md', title: 'Позволяет узлам дерева получать фокус при их выделении', color: 'green' },
    { label: 'allowCheck', src: './$info/props/allow-check.md', title: 'Позволяет отображать дополнительные кнопки выбора узлов дерева', color: 'red', error: 'Событие checked при выборе кнопки не срабатывает из-за того, что функции getParentItem в _toggleChecked table.js нет' },
    { label: 'autoWidth', src: './$info/props/auto-width.md', title: 'Позволяет привязать ширину столбца к ширине всего контейнера, в котором отображаются узлы дерева', color: 'green' },
    { label: 'evenOdd', src: './$info/props/even-odd.md', title: 'Позволяет отображать четные и нечетные строки разным стилем', color: 'green' },
    { label: 'showFooter', src: './$info/props/show-footer.md', title: 'Позволяет отображать нижний колонтитул дерева', color: 'red', error: "./_error/show-footer.md" },
    { label: 'showFilterRow', src: './$info/props/show-filter-row.md', title: 'Позволяет отобразить строку для фильтрации узлов дерева', color: 'red' , error: 'Это свойство вообще ничего не задает. Оно появляется только в наблюдателе, но и там нигде не используется'},
    { label: 'defaultHeader', src: './$info/props/default-header.md', title: 'Задает имя компонента, который будут использоваться для отображения заголовка дерева по умолчанию', color: 'green' },
    { label: 'defaultTemplate', src: './$info/props/default-template.md', title: 'Задает имя компонента, который будет используется для отображения узлов дерева по умолчанию', color: 'green' },
    { label: 'defaultFooter', src: './$info/props/default-footer.md', title: 'Задает имя компонента, который будет использоваться для отображения нижнего колонтитула дерева', color: 'green' },
    { label: 'defaultGroupTemplate', src: './$info/props/default-group-template.md', title: 'Определяет компонент, который используется для отображения строки группировки узлов дерева', color: 'red', error: 'Столбец перетаскивается, но строки не группируются' },
    { label: 'showBorders', src: './$info/props/show-borders.md', title: 'Задает дополнительную рамку по периметру компонента', color: 'red', error: 'Если отображаются линии строк и столбцов, то бордюр накладывается на них. Получается некрасиво' },
    { label: 'showGroupingPanel', src: './$info/props/show-grouping-panel.md', title: 'Позволяет отобразить специальную панель для группировки узлов дерева', color: 'yellow', error: 'Группировка происходит, но столбец с группировочной панели не удаляется. Самая группировка начинает отображаться, когда переоткроешь список дочерних узлов' },
    { label: 'showGroupFooter', src: './$info/props/show-group-footer.md', title: 'Позволяет отобразить нижний колонтитул в конце каждой группы', color: 'red', error: 'Футер появляется, но на нем ничего не отображается. Фактически в группу просто добавляется пустая строка, у которой есть роль footer, и в стилях она отображается как заголовок' },
    { label: 'hideRoot', src: './$info/props/hide-root.md', title: 'Позволяет спрятать корневые узлы дерева', color: 'red', error: 'Он прячет корневые узлы не только деревьев, но и обычных столбцов' },
    { label: 'treeStep', src: './$info/props/tree-step.md', title: 'Задает дополнительный отступ при перетаскивании узла', color: 'red', error: "Технология drag and drop не работает. Узлы не перемещаются." },
    { label: 'colLines', src: './$info/props/col-lines.md', title: 'Позволяет отобразить горизонтальные линии в конце каждой строки дерева', color: 'green' },
    { label: 'rowLines', src: './$info/props/row-lines.md', title: 'Позволяет отобразить вертикальные линии, разделяющие строки дерева', color: 'green' },
    { label: 'showFilter', src: './$info/props/show-filter.md', title: 'Позволяет отображать панель фильтрации узлов дерева', color: 'red', error: 'Компонента ввода фильтра не с чем не связан. Он вводит фильтр' },
    { label: 'allowDrag', src: './$info/props/allow-drag.md', title: 'Позволяет перетаскивать узлы дерева', color: 'green' },
    { label: 'focusedRow', src: './$info/props/focused-row.md', title: 'Содержит указатель на узел, который находится в фокусе', color: 'green' },
    { label: 'showHeader', src: './$info/props/show-header.md', title: 'Позволяет отобразить панель заголовка', color: 'yellow', error: 'Если массив columns не задан, то название не выводится' },
    { label: 'allowDrop', src: './$info/props/allow-drop.md', title: 'Позволяет вставлять узлы дерева при их перетаскивании', color: 'red' },
    { label: 'columns', src: './$info/props/columns.md', title: 'Содержит список столбцов', color: 'red', error: 'Это свойство используется во многих режимах, но заданное по умолчанию свойство cols не дает этого сделать. columns по умолчанию остается пустым и все остальные режимы просто отваливаются'},
    { label: 'colsHead', src: './$info/props/cols-head.md', title: 'Содержит преобразованный массив заголовков столбцов таблицы', color: 'green'},
    { label: 'cols', src: './$info/props/cols.md', title: 'Содержит массив столбцов только с вложенными заголовками', color: 'red', error: 'При развертывании столбцов вложенные строки не прорисовываются. При свертывании вложенных заголовком массив cols не обновляется' },
    { label: 'dataSet', src: './$info/props/data-set.md', title: 'Содержит исходный набор данных для построения дерева', color: 'green' },
    { label: 'expanding', src: './$info/props/expanding.md', title: 'Сигнализирует о том, что идет процесс свертывания или развертывания узлов дерева', color: 'red',  error: "Вообще нигде не учитывается. Функции expandAll и collapseAll не используют это свойство"},
]

==> oda-framework-0.1.72684.tgz: package/components/grids/table/$info/props/_info.js <==
export default [
    { label: 'size', src: './$info/props/size.md', title: 'Количество строк, которые находятся на данный момент в дереве', color: 'green' },
    { label: 'items', src: './$info/props/items.md', title: 'Содержит список всех развернутых узлов, которые находятся в контейнере дерева на данный момент', color: 'green' },
    { label: 'iconSize', src: './$info/props/icon-size.md', title: 'Задает высоту строк, которые используются для отображения узлов дерева с иконками или без них', color: 'yellow', error: 'Если задаешь свойство icon в списке узлов dataSet, то иконка не выводится. Нужно создавать пользовательский шаблон. Это очень не удобно использовать'},
    { label: 'showTreeLines', src: './$info/props/show-tree-lines.md', title: 'Показывает горизонтальные линии у узлов дерева, расположенных на одном и том же уровне', color: 'yellow', error: 'Направляющие линии отображаются ниже узлов. При изменении свойства отображение линий не меняется' },
    { label: 'categories', src: './$info/props/categories.md', title: 'содержит дополнительные настройки, которые используются в процессе группировки узлов дерева', color: 'green' },
    { label: 'selectAll', src: './$info/props/select-all.md', title: 'Позволяет выбрать все узлы дерева', color: 'green' },
    { label: 'allowSort', src: './$info/props/allow-sort.md', title: 'Позволяет сортировать узлы дерева по возрастанию или убыванию', color: 'red', error: 'Стрелка для сортировки изначально не появляется. Сортировка идет только по убыванию. При сортировке по возрастанию списка узлов не обновляется, но если развернуть вложенный узел, то они сортируются. После отмены сортировки толи не возвращает все обратно, толи просто не обновляет' },
    { label: 'screen', src: './$info/props/screen.md', title: 'Содержит объект, позволяющий определить, какие узлы умещаются в видимой области контейнера, какие отсортированы и/или отфильтрованы', color: 'green' },
    { label: 'idName', src: './$info/props/idName.md', title: 'Задает уникальный идентификатор строки', color: 'red', error: 'Оно просто содержит ошибку, это не массив в 166 строке table.js' },
    { label: 'lazy', src: './$info/props/lazy.md', title: 'Позволяет ускорить обработку узлов дерева, исключив из общего списка не отображаемые узлы', color: 'red', error: 'При наличии футора он не не правильно считает количество видимых строк в контейнере. Он одну лишнюю добавляет' },
    { label: 'loadingTemplate', src: './$info/props/loading-template.md', title: 'Содержит имя компонента, который используется для отображения узлов в режиме ожидания окончания загрузки их дочерних узлов', color: 'green' },
    { label: 'footer', src: './$info/props/footer.md', title: 'Позволяет узнать содержимое нижнего колонтитула дерева', color: 'green' },
    { label: 'rows', src: './$info/props/rows.md', title: 'Содержит список всех узлов, которые необходимы для обработки узлов в видимой области контейнера дерева',  color: 'green' },
    { label: 'table', src: './$info/props/table.md', title: 'Содержит указатель на сам компонент', color: 'red' },
    { label: 'allowSelection', src: './$info/props/allow-selection.md', title: 'Включает режим, позволяющий выбирать необходимые узлы дерева', color: 'green' },
    { label: 'selection', src: './$info/props/selection.md', title: 'Содержит список всех выбранных узлов дерева', color: 'red', error: 'При выборе всех строк selectAll массив не заполняется' },
    { label: 'settingsId', src: './$info/props/settings-id.md', title: 'Задает имя, которое используется при чтении или сохранении некоторых текущих настроек компонента в локальном хранилище', color: 'green' },
    { label: 'headerHeight', src: './$info/props/header-height.md', title: 'Позволяет определить высоту заголовка компонента', color: 'green' },
    { label: 'footerHeight', src: './$info/props/footer-height.md', title: 'Позволяет определить высоту нижнего колонтитула компонента', color: 'red', error: 'Не пересчитывает высоту. Она всегда остается 0' },
    { label: 'filters', src: './$info/props/filters.md', title: 'Содержит массив столбцов, в которых включен режим фильтрации узлов дерева', color: 'red', error: 'Любой заданный фильтр убирает все строки таблицы' },
    { label: 'sorts', src: './$info/props/sorts.md', title: 'Содержит массив столбцов, которые находятся в режиме сортировки', color: 'red', error: 'если не задан явно массив columns, то сортировка не работает. Проблема с cols. Иконка сортировки изначально не появляется. Сортировка узлов не обновляется до переоткрытия узлов в ручном режиме.' },
    { label: 'groups', src: './$info/props/groups.md', title: 'Содержит массив столбцов, по которым осуществляется группировка узлов дерева на данный момент', color: 'yellow', error: 'С массивом все хорошо, но группировка отображается только тогда, когда переоткроешь какую-нибудь группу' },
    { label: 'allowFocus', src: './$info/props/allow-focus.md', title: 'Позволяет узлам дерева получать фокус при их выделении', color: 'green' },
    { label: 'allowCheck', src: './$info/props/allow-check.md', title: 'Позволяет отображать дополнительные кнопки выбора узлов дерева', color: 'red', error: 'Событие checked при выборе кнопки не срабатывает из-за того, что функции getParentItem в _toggleChecked table.js нет' },
    { label: 'autoWidth', src: './$info/props/auto-width.md', title: 'Позволяет привязать ширину столбца к ширине всего контейнера, в котором отображаются узлы дерева', color: 'green' },
    { label: 'evenOdd', src: './$info/props/even-odd.md', title: 'Позволяет отображать четные и нечетные строки разным стилем', color: 'green' },
    { label: 'showFooter', src: './$info/props/show-footer.md', title: 'Позволяет отображать нижний колонтитул дерева', color: 'red', error: "./_error/show-footer.md" },
    { label: 'showFilterRow', src: './$info/props/show-filter-row.md', title: 'Позволяет отобразить строку для фильтрации узлов дерева', color: 'red' , error: 'Это свойство вообще ничего не задает. Оно появляется только в наблюдателе, но и там нигде не используется'},
    { label: 'headerTemplate', src: './$info/props/default-header.md', title: 'Задает имя компонента, который будут использоваться для отображения заголовка дерева по умолчанию', color: 'green' },
    { label: 'cellTemplate', src: './$info/props/default-template.md', title: 'Задает имя компонента, который будет используется для отображения узлов дерева по умолчанию', color: 'green' },
    { label: 'footerTemplate', src: './$info/props/default-footer.md', title: 'Задает имя компонента, который будет использоваться для отображения нижнего колонтитула дерева', color: 'green' },
    { label: 'groupTemplate', src: './$info/props/default-group-template.md', title: 'Определяет компонент, который используется для отображения строки группировки узлов дерева', color: 'red', error: 'Столбец перетаскивается, но строки не группируются' },
    { label: 'showBorders', src: './$info/props/show-borders.md', title: 'Задает дополнительную рамку по периметру компонента', color: 'red', error: 'Если отображаются линии строк и столбцов, то бордюр накладывается на них. Получается некрасиво' },
    { label: 'showGroupingPanel', src: './$info/props/show-grouping-panel.md', title: 'Позволяет отобразить специальную панель для группировки узлов дерева', color: 'yellow', error: 'Группировка происходит, но столбец с группировочной панели не удаляется. Самая группировка начинает отображаться, когда переоткроешь список дочерних узлов' },
    { label: 'showGroupFooter', src: './$info/props/show-group-footer.md', title: 'Позволяет отобразить нижний колонтитул в конце каждой группы', color: 'red', error: 'Футер появляется, но на нем ничего не отображается. Фактически в группу просто добавляется пустая строка, у которой есть роль footer, и в стилях она отображается как заголовок' },
    { label: 'hideRoot', src: './$info/props/hide-root.md', title: 'Позволяет спрятать корневые узлы дерева', color: 'red', error: 'Он прячет корневые узлы не только деревьев, но и обычных столбцов' },
    { label: 'treeStep', src: './$info/props/tree-step.md', title: 'Задает дополнительный отступ при перетаскивании узла', color: 'red', error: "Технология drag and drop не работает. Узлы не перемещаются." },
    { label: 'colLines', src: './$info/props/col-lines.md', title: 'Позволяет отобразить горизонтальные линии в конце каждой строки дерева', color: 'green' },
    { label: 'rowLines', src: './$info/props/row-lines.md', title: 'Позволяет отобразить вертикальные линии, разделяющие строки дерева', color: 'green' },
    { label: 'showFilter', src: './$info/props/show-filter.md', title: 'Позволяет отображать панель фильтрации узлов дерева', color: 'red', error: 'Компонента ввода фильтра не с чем не связан. Он вводит фильтр' },
    { label: 'allowDrag', src: './$info/props/allow-drag.md', title: 'Позволяет перетаскивать узлы дерева', color: 'green' },
    { label: 'focusedRow', src: './$info/props/focused-row.md', title: 'Содержит указатель на узел, который находится в фокусе', color: 'green' },
    { label: 'showHeader', src: './$info/props/show-header.md', title: 'Позволяет отобразить панель заголовка', color: 'yellow', error: 'Если массив columns не задан, то название не выводится' },
    { label: 'allowDrop', src: './$info/props/allow-drop.md', title: 'Позволяет вставлять узлы дерева при их перетаскивании', color: 'red' },
    { label: 'columns', src: './$info/props/columns.md', title: 'Содержит список столбцов', color: 'red', error: 'Это свойство используется во многих режимах, но заданное по умолчанию свойство cols не дает этого сделать. columns по умолчанию остается пустым и все остальные режимы просто отваливаются'},
    { label: 'colsHead', src: './$info/props/cols-head.md', title: 'Содержит преобразованный массив заголовков столбцов таблицы', color: 'green'},
    { label: 'cols', src: './$info/props/cols.md', title: 'Содержит массив столбцов только с вложенными заголовками', color: 'red', error: 'При развертывании столбцов вложенные строки не прорисовываются. При свертывании вложенных заголовком массив cols не обновляется' },
    { label: 'dataSet', src: './$info/props/data-set.md', title: 'Содержит исходный набор данных для построения дерева', color: 'green' },
    { label: 'expanding', src: './$info/props/expanding.md', title: 'Сигнализирует о том, что идет процесс свертывания или развертывания узлов дерева', color: 'red',  error: "Вообще нигде не учитывается. Функции expandAll и collapseAll не используют это свойство"},
]
